@@ -8,7 +8,7 @@ use base qw( Exporter );
 our @EXPORT = grep /^arguments_/, keys %FFI::Platypus::API::;
 
 # ABSTRACT: Platypus arguments and return value API for custom types
-our $VERSION = '0.56'; # VERSION
+our $VERSION = '0.96'; # VERSION
 
 
 1;
@@ -25,7 +25,7 @@ FFI::Platypus::API - Platypus arguments and return value API for custom types
 
 =head1 VERSION
 
-version 0.56
+version 0.96
 
 =head1 SYNOPSIS
 
@@ -50,13 +50,19 @@ version 0.56
 
 =head1 DESCRIPTION
 
-The custom types API for L<FFI::Platypus> allows you to set multiple C 
-arguments from a single Perl argument as a common type.  This is 
-sometimes useful for pointer / size pairs which are a common pattern in 
-C, but are usually represented by a single value (a string scalar) in 
+B<NOTE>: I added this interface early on to L<FFI::Platypus>, but haven't
+used it much, generally finding function wrappers to be a more powerful
+(although possibly not as fast) interface.  It has thus not been
+tested as much as the rest of Platypus.  If you feel the need to use
+this interface please coordinate with the Platypus developers.
+
+The custom types API for L<FFI::Platypus> allows you to set multiple C
+arguments from a single Perl argument as a common type.  This is
+sometimes useful for pointer / size pairs which are a common pattern in
+C, but are usually represented by a single value (a string scalar) in
 Perl.
 
-The custom type API is somewhat experimental, and you should expect some 
+The custom type API is somewhat experimental, and you should expect some
 changes as needs arise (I won't break compatibility lightly, however).
 
 =head1 FUNCTIONS
@@ -187,7 +193,7 @@ Get the double precision floating point argument from position I<$i>.
 
  arguments_set_double $i, $double;
 
-Set the double precision floating point argument at position I<$i> to 
+Set the double precision floating point argument at position I<$i> to
 I<$double>
 
 =head2 arguments_get_pointer
@@ -256,9 +262,15 @@ Damyan Ivanov
 
 Ilya Pavlov (Ilya33)
 
+Petr Pisar (ppisar)
+
+Mohammad S Anwar (MANWAR)
+
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
