@@ -6,7 +6,7 @@ use Carp ();
 use FFI::Platypus;
 
 # ABSTRACT: Declarative interface to FFI::Platypus
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '0.96'; # VERSION
 
 
 our $ffi    = {};
@@ -118,7 +118,7 @@ sub import
 {
   my $caller = caller;
   shift; # class
-  
+
   foreach my $arg (@_)
   {
     if(ref $arg)
@@ -143,7 +143,7 @@ sub import
       *{join '::', $caller, $arg} = sub () { $arg };
     }
   }
-  
+
   no strict 'refs';
   *{join '::', $caller, 'lib'} = \&lib;
   *{join '::', $caller, 'type'} = \&type;
@@ -174,12 +174,12 @@ FFI::Platypus::Declare - Declarative interface to FFI::Platypus
 
 =head1 VERSION
 
-version 0.83
+version 0.96
 
 =head1 SYNOPSIS
 
  use FFI::Platypus::Declare 'string', 'int';
-
+ 
  lib undef; # use libc
  attach puts => [string] => int;
  
@@ -199,12 +199,12 @@ provides most of the goals this module was intended for (that is
 a simple interface at the cost of some power), without much of the
 complexity.  The remainder of this document describes the interface.
 
-This module provides a declarative interface to L<FFI::Platypus>. It 
-provides a more concise interface at the cost of a little less power, 
+This module provides a declarative interface to L<FFI::Platypus>. It
+provides a more concise interface at the cost of a little less power,
 and a little more namespace pollution.
 
-Any strings passed into the C<use> line will be declared as types and 
-exported as constants into your namespace, so that you can use them 
+Any strings passed into the C<use> line will be declared as types and
+exported as constants into your namespace, so that you can use them
 without quotation marks.
 
 Aliases can be declared using a list reference:
@@ -226,8 +226,8 @@ then use the OO interface (see L<FFI::Platypus>).
 
  lib $libpath;
 
-Specify one or more dynamic libraries to search for symbols. If you are 
-unsure of the location / version of the library then you can use 
+Specify one or more dynamic libraries to search for symbols. If you are
+unsure of the location / version of the library then you can use
 L<FFI::CheckLib#find_lib>.
 
 =head2 type
@@ -246,20 +246,20 @@ Examples:
 
  custom_type $alias => \%args;
 
-Declare the given custom type.  See L<FFI::Platypus::Type#Custom-Types> 
+Declare the given custom type.  See L<FFI::Platypus::Type#Custom-Types>
 for details.
 
 =head2 load_custom_type
 
  load_custom_type $name => $alias, @type_args;
 
-Load the custom type defined in the module I<$name>, and make an alias 
-with the name I<$alias>. If the custom type requires any arguments, they 
-may be passed in as I<@type_args>. See L<FFI::Platypus::Type#Custom 
-Types> for details.
+Load the custom type defined in the module I<$name>, and make an alias
+with the name I<$alias>. If the custom type requires any arguments, they
+may be passed in as I<@type_args>. See L<FFI::Platypus::Type#Custom-Types>
+for details.
 
-If I<$name> contains C<::> then it will be assumed to be a fully 
-qualified package name. If not, then C<FFI::Platypus::Type::> will be 
+If I<$name> contains C<::> then it will be assumed to be a fully
+qualified package name. If not, then C<FFI::Platypus::Type::> will be
 prepended to it.
 
 =head2 type_meta
@@ -280,9 +280,9 @@ Example:
 
 Find and attach a C function as a Perl function as a real live xsub.
 
-If just one I<$name> is given, then the function will be attached in 
-Perl with the same name as it has in C.  The second form allows you to 
-give the Perl function a different name.  You can also provide a memory 
+If just one I<$name> is given, then the function will be attached in
+Perl with the same name as it has in C.  The second form allows you to
+give the Perl function a different name.  You can also provide a memory
 address (the third form) of a function to attach.
 
 Examples:
@@ -307,20 +307,20 @@ Example:
 
  my $closure = sticky closure $codeblock;
 
-Keyword to indicate the closure should not be deallocated for the life 
+Keyword to indicate the closure should not be deallocated for the life
 of the current process.
 
-If you pass a closure into a C function without saving a reference to it 
+If you pass a closure into a C function without saving a reference to it
 like this:
 
  foo(closure { ... });         # BAD
 
-Perl will not see any references to it and try to free it immediately.  
-(this has to do with the way Perl and C handle responsibilities for 
-memory allocation differently).  One fix for this is to make sure the 
-closure remains in scope using either C<my> or C<our>.  If you know the 
-closure will need to remain in existence for the life of the process (or 
-if you do not care about leaking memory), then you can add the sticky 
+Perl will not see any references to it and try to free it immediately.
+(this has to do with the way Perl and C handle responsibilities for
+memory allocation differently).  One fix for this is to make sure the
+closure remains in scope using either C<my> or C<our>.  If you know the
+closure will need to remain in existence for the life of the process (or
+if you do not care about leaking memory), then you can add the sticky
 keyword to tell L<FFI::Platypus> to keep the thing in memory.
 
  foo(sticky closure { ... });  # OKAY
@@ -329,9 +329,9 @@ keyword to tell L<FFI::Platypus> to keep the thing in memory.
 
  my $converted_value = cast $original_type, $converted_type, $original_value;
 
-The C<cast> function converts an existing I<$original_value> of type 
-I<$original_type> into one of type I<$converted_type>.  Not all types 
-are supported, so care must be taken.  For example, to get the address 
+The C<cast> function converts an existing I<$original_value> of type
+I<$original_type> into one of type I<$converted_type>.  Not all types
+are supported, so care must be taken.  For example, to get the address
 of a string, you can do this:
 
  my $address = cast 'string' => 'opaque', $string_value;
@@ -341,22 +341,22 @@ of a string, you can do this:
  attach_cast "cast_name", $original_type, $converted_type;
  my $converted_value = cast_name($original_value);
 
-This function creates a subroutine which can be used to convert 
-variables just like the L<cast|FFI::Platypus::Declare#cast> function 
+This function creates a subroutine which can be used to convert
+variables just like the L<cast|FFI::Platypus::Declare#cast> function
 above.  The above synopsis is roughly equivalent to this:
 
  sub cast_name { cast($original_type, $converted_type, $_[0]) }
  my $converted_value = cast_name($original_value);
 
-Except that the L<attach_cast|FFI::Platypus::Declare#attach_cast> 
-variant will be much faster if called multiple times since the cast does 
+Except that the L<attach_cast|FFI::Platypus::Declare#attach_cast>
+variant will be much faster if called multiple times since the cast does
 not need to be dynamically allocated on each instance.
 
 =head2 sizeof
 
  my $size = sizeof $type;
 
-Returns the total size of the given type.  For example to get the size 
+Returns the total size of the given type.  For example to get the size
 of an integer:
 
  my $intsize = sizeof 'int'; # usually 4 or 8 depending on platform
@@ -365,22 +365,22 @@ You can also get the size of arrays
 
  my $intarraysize = sizeof 'int[64]';
 
-Keep in mind that "pointer" types will always be the pointer / word size 
-for the platform that you are using.  This includes strings, opaque and 
+Keep in mind that "pointer" types will always be the pointer / word size
+for the platform that you are using.  This includes strings, opaque and
 pointers to other types.
 
-This function is not very fast, so you might want to save this value as 
-a constant, particularly if you need the size in a loop with many 
+This function is not very fast, so you might want to save this value as
+a constant, particularly if you need the size in a loop with many
 iterations.
 
 =head2 lang
 
  lang $language;
 
-Specifies the foreign language that you will be interfacing with. The 
-default is C.  The foreign language specified with this attribute 
-changes the default native types (for example, if you specify 
-L<Rust|FFI::Platypus::Lang::Rust>, you will get C<i32> as an alias for 
+Specifies the foreign language that you will be interfacing with. The
+default is C.  The foreign language specified with this attribute
+changes the default native types (for example, if you specify
+L<Rust|FFI::Platypus::Lang::Rust>, you will get C<i32> as an alias for
 C<sint32> instead of C<int> as you do with L<C|FFI::Platypus::Lang::C>).
 
 In the future this may attribute may offer hints when doing demangling
@@ -450,6 +450,12 @@ Damyan Ivanov
 
 Ilya Pavlov (Ilya33)
 
+Petr Pisar (ppisar)
+
+Mohammad S Anwar (MANWAR)
+
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
